changeset 1031:31c9d3b5007a

move templates and static files into a theme directory The two are very related so they should be stored in the same place. Signed-off-by: Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
author Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
date Fri, 24 Jul 2020 14:21:47 -0400
parents a072edad2d3f
children c0d131c337eb
files config.cmake samples/full.lisp templates/atom/comment.tmpl templates/atom/commentlist.tmpl templates/atom/index.tmpl templates/atom/story.tmpl templates/atom/storyview.tmpl templates/atom/tag.tmpl templates/common/storyview.tmpl templates/html/301.tmpl templates/html/404.tmpl templates/html/archive.tmpl templates/html/archivepager.tmpl templates/html/comment.tmpl templates/html/comment_error.tmpl templates/html/comment_saved.tmpl templates/html/commentform.tmpl templates/html/error_comment_feed.tmpl templates/html/error_unsupported_feed_fmt.tmpl templates/html/footer.tmpl templates/html/fullstory.tmpl templates/html/header.tmpl templates/html/index.tmpl templates/html/indexpager.tmpl templates/html/sidebar.tmpl templates/html/story.tmpl templates/html/storyview.tmpl templates/html/tag.tmpl templates/html/tagcloud.tmpl templates/html/tagindex.tmpl templates/html/tagpager.tmpl templates/rss2/comment.tmpl templates/rss2/commentlist.tmpl templates/rss2/index.tmpl templates/rss2/story.tmpl templates/rss2/storyview.tmpl templates/rss2/tag.tmpl theme/atom/comment.tmpl theme/atom/commentlist.tmpl theme/atom/index.tmpl theme/atom/story.tmpl theme/atom/storyview.tmpl theme/atom/tag.tmpl theme/common/storyview.tmpl theme/html/301.tmpl theme/html/404.tmpl theme/html/archive.tmpl theme/html/archivepager.tmpl theme/html/comment.tmpl theme/html/comment_error.tmpl theme/html/comment_saved.tmpl theme/html/commentform.tmpl theme/html/error_comment_feed.tmpl theme/html/error_unsupported_feed_fmt.tmpl theme/html/footer.tmpl theme/html/fullstory.tmpl theme/html/header.tmpl theme/html/index.tmpl theme/html/indexpager.tmpl theme/html/sidebar.tmpl theme/html/story.tmpl theme/html/storyview.tmpl theme/html/tag.tmpl theme/html/tagcloud.tmpl theme/html/tagindex.tmpl theme/html/tagpager.tmpl theme/rss2/comment.tmpl theme/rss2/commentlist.tmpl theme/rss2/index.tmpl theme/rss2/story.tmpl theme/rss2/storyview.tmpl theme/rss2/tag.tmpl theme/static/bug.png theme/static/favicon.ico theme/static/style.css theme/static/wiki.png web/bug.png web/favicon.ico web/style.css web/wiki.png
diffstat 80 files changed, 587 insertions(+), 586 deletions(-) [+]
line wrap: on
line diff
--- a/config.cmake	Thu Jul 30 16:57:38 2020 -0400
+++ b/config.cmake	Fri Jul 24 14:21:47 2020 -0400
@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2016-2019 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
+# Copyright (c) 2016-2020 Josef 'Jeff' Sipek <jeffpc@josefsipek.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -45,8 +45,8 @@
 set_default(DEFAULT_COMMENT_MIN_THINK	10)	# 10 secs min think time
 
 set_default(DEFAULT_DATA_DIR		"./data")
-set_default(DEFAULT_WEB_DIR		"./web")
-set_default(DEFAULT_TEMPLATE_DIR	"./templates")
+set_default(DEFAULT_WEB_DIR		"./theme/static")
+set_default(DEFAULT_TEMPLATE_DIR	"./theme")
 
 set_default(BASE_URL			"http://blahg.josefsipek.net")
 set_default(BUG_BASE_URL		"http://bugs.31bits.net")
--- a/templates/atom/comment.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,14 +0,0 @@
-<entry>
-	<author>
-		<name>{commauthor|escape}</name>
-		<uri>{baseurl}/p={id}#comment-{commid}</uri>
-	</author>
-	<title type="html"><![CDATA[By: {commauthor}]]></title>
-	<link rel="alternate" type="text/html" href="{baseurl}/?p={id}#comment-{commid}" />
-	<id>{baseurl}/?p={id}#comment-{commid}</id>
-	<updated>{commtime|zulu}</updated>
-	<published>{commtime|zulu}</published>
-
-	<summary type="html"><![CDATA[{commbody}]]></summary>
-	<content type="html" xml:base="{baseurl}/?p={id}#comment-{commid}"><![CDATA[{commbody}]]></content>
-</entry>
--- a/templates/atom/commentlist.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,18 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<feed
-  xmlns="http://www.w3.org/2005/Atom"
-  xmlns:thr="http://purl.org/syndication/thread/1.0"
-  xml:lang="en"
-  xml:base="{baseurl}/?p={id}&amp;feed=atom"
-   >
-	<updated>{time|zulu}</updated>
-	<title type="text">Comments on: {title|escape}</title>
-
-	<generator uri="http://hg.31bits.net/blahgd/blahgd" version="{generatorversion}">blahgd</generator>
-
-	<link rel="alternate" type="text/html" href="{baseurl}" />
-	<id>{baseurl}/?p={id}&amp;feed=atom</id>
-	<link rel="self" type="application/atom+xml" href="{baseurl}/?p={id}&amp;feed=atom" />
-
-{comments%comment}
-</feed>
--- a/templates/atom/index.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,19 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<feed
-  xmlns="http://www.w3.org/2005/Atom"
-  xmlns:thr="http://purl.org/syndication/thread/1.0"
-  xml:lang="en"
-  xml:base="{baseurl}/?feed=atom"
-   >
-	<updated>{lastupdate|zulu}</updated>
-	<title type="text">Josef "Jeff" Sipek</title>
-	<subtitle type="text">Wasting time effectively</subtitle>
-
-	<generator uri="http://hg.31bits.net/blahgd/blahgd" version="{generatorversion}">blahgd</generator>
-
-	<link rel="alternate" type="text/html" href="{baseurl}" />
-	<id>{baseurl}/?feed=atom</id>
-	<link rel="self" type="application/atom+xml" href="{baseurl}/?feed=atom" />
-
-{posts%story}
-</feed>
--- a/templates/atom/story.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,17 +0,0 @@
-<entry>
-	<author>
-		<name>JeffPC</name>
-		<uri>{baseurl}</uri>
-	</author>
-	<title type="html"><![CDATA[{title}]]></title>
-	<link rel="alternate" type="text/html" href="{baseurl}/?p={id}" />
-	<id>{baseurl}/?p={id}</id>
-	<updated>{time|zulu}</updated>
-	<published>{time|zulu}</published>
-
-	<link rel="replies" type="text/html" href="{baseurl}/?p={id}#comments" thr:count="1"/>
-	<thr:total>{numcom}</thr:total>
-	{tags%tag}
-	<summary type="html"><![CDATA[{body}]]></summary>
-	<content type="html" xml:base="{baseurl}/?p={id}"><![CDATA[{body}]]></content>
-</entry>
--- a/templates/atom/storyview.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,1 +0,0 @@
-../common/storyview.tmpl
\ No newline at end of file
--- a/templates/atom/tag.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,1 +0,0 @@
-	<category scheme="{baseurl}" term="{tags}" />
--- a/templates/common/storyview.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,1 +0,0 @@
-{posts%commentlist}
--- a/templates/html/301.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,8 +0,0 @@
-<html>
-<head>
-<title>301 Moved Permanently</title>
-</head>
-<body>
-Moved permanently to <a href="{redirect}">{redirect}</a>.
-</body>
-</html>
--- a/templates/html/404.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,9 +0,0 @@
-{header}
-<h2>Page Not Found</h2>
-<div class="post" id="error">
-	<div class="storycontent">
-The page you requested could not be found.
-	</div>
-</div>
-{sidebar}
-{footer}
--- a/templates/html/archive.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,5 +0,0 @@
-{header}
-{posts%story}
-{archivepager}
-{sidebar}
-{footer}
--- a/templates/html/archivepager.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,8 +0,0 @@
-<div class="navigation">
-	{ifeq(moreposts,1)}
-	<div class="alignleft"><a href="?m={archid}&amp;paged={prevpage}">&laquo; Older Entries</a></div>
-	{endif()}
-	{ifgt(curpage,0)}
-	<div class="alignright"><a href="?m={archid}&amp;paged={nextpage}">Newer Entries &raquo;</a></div>
-	{endif()}
-</div>
--- a/templates/html/comment.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,4 +0,0 @@
-	<li id="comment-{commid}">
-{commbody}
-	<p><cite>Comment by {commauthor} &#8212; {commtime|date} @ <a href="#comment-{commid}">{commtime|time}</a></cite></p>
-	</li>
--- a/templates/html/comment_error.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,8 +0,0 @@
-{header}
-<h4>Error Saving Comment</h4>
-
-<p>{comment_error_str}</p>
-
-<p>Press the back button in your browser, and try again.</p>
-{sidebar}
-{footer}
--- a/templates/html/comment_saved.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,4 +0,0 @@
-{header}
-<h4>Your comment has been held for moderation. Thank you.</h4>
-{sidebar}
-{footer}
--- a/templates/html/commentform.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,31 +0,0 @@
-<div id="respond">
-<h2>Leave a comment</h2>
-
-<form action="?comment=1" method="post" id="commentform">
-
-<p style="display: none;">
-<input type="text" name="x" id="name" value="" size="22" />
-<label for="name"><small>Please do not enter anything here</small></label>
-</p>
-
-<p><input type="text" name="a" id="author" value="" size="22" tabindex="1" />
-<label for="author"><small>Name (required)</small></label></p>
-
-<p><input type="text" name="e" id="email" value="" size="22" tabindex="2" />
-<label for="email"><small>Mail (will not be published) (required)</small></label></p>
-
-<p><input type="text" name="u" id="url" value="" size="22" tabindex="3" />
-<label for="url"><small>Website</small></label></p>
-
-<p><input type="text" name="v" id="captcha" value="" size="22" tabindex="4" />
-<label for="captcha"><small>{captcha_a} + {captcha_b} (required)</small></label></p>
-
-<p><textarea name="c" id="comment" cols="100%" rows="10" tabindex="5"></textarea></p>
-
-<p><input name="s" type="submit" id="submit" tabindex="6" value="Submit Comment" />
-<input type="hidden" name="i" value="{id}" />
-<input type="hidden" name="d" value="{now}" />
-</p>
-
-</form>
-</div>
--- a/templates/html/error_comment_feed.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,10 +0,0 @@
-{header}
-<h2>Comment feed not yet supported</h2>
-<div class="post" id="error">
-	<div class="storycontent">
-	It turns out that there are some features that I never got around to
-	implementing.  You just found one of them.  Eventually.
-	</div>
-</div>
-{sidebar}
-{footer}
--- a/templates/html/error_unsupported_feed_fmt.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,10 +0,0 @@
-{header}
-<h2>Sorry, Atom &amp; RSS2 only</h2>
-<div class="post" id="error">
-	<div class="storycontent">
-	Sorry, currently I support only Atom and RSS2 feeds.  Feel free to
-	contact me if you cannot live without some other feed format.
-	</div>
-</div>
-{sidebar}
-{footer}
--- a/templates/html/footer.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,9 +0,0 @@
-
-<!-- begin footer -->
-
-<p class="credit"><cite>Powered by <a href='http://hg.31bits.net/blahgd/blahgd' title='Powered by blahgd'><strong>blahgd</strong></a></cite></p>
-
-</div>
-
-</body>
-</html>
--- a/templates/html/fullstory.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,12 +0,0 @@
-{story}
-<h2>{numcom} Comments <a href="#respond" title="Leave a comment">&raquo;</a></h2>
-
-{ifgt(numcom,0)}
-<ol id="commentlist">
-{comments%comment}
-</ol>
-{endif()}
-
-<p><a href='{baseurl}/?p={id}&amp;feed=atom'>Atom feed for comments on this post.</a></p>
-
-{commentform}
--- a/templates/html/header.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,38 +0,0 @@
-<!DOCTYPE html>
-<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
-<head>
-	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
-	<title>Josef &#8220;Jeff&#8221; Sipek &raquo; {title|escape}</title>
-	<meta name="generator" content="blahgd {generatorversion}" />
-{ifset(twitteruser)}
-{ifset(twittertitle)}
-{ifset(twitterdesc)}
-	<meta name="twitter:site" content="@{twitteruser}" />
-	<meta name="twitter:creator" content="@{twitteruser}" />
-	<meta name="twitter:title" content="{twittertitle|escape}" />
-	<meta name="twitter:description" content="{twitterdesc|escape}" />
-{ifset(twitterimg)}
-	<meta name="twitter:image" content="{twitterimg}" />
-	<meta name="twitter:card" content="summary_large_image" />
-{else()}
-	<meta name="twitter:card" content="summary" />
-{endif()}
-{endif()}
-{endif()}
-{endif()}
-	<style media="screen">
-		@import url( {baseurl}/style.css );
-	</style>
-
-	<link rel="shortcut icon" href="{baseurl}/favicon.ico" />
-	<link rel="alternate" type="application/atom+xml" title="Atom 0.3" href="{baseurl}/?feed=atom" />
-	<link rel="alternate" type="application/rss+xml" title="RSS2" href="{baseurl}/?feed=rss2" />
-</head>
-<body>
-
-<div>
-<h1 id="header"><a href="{baseurl}/">Josef &#8220;Jeff&#8221; Sipek</a></h1>
-
-<div id="content">
-<!-- end header -->
-
--- a/templates/html/index.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,5 +0,0 @@
-{header}
-{posts%story}
-{indexpager}
-{sidebar}
-{footer}
--- a/templates/html/indexpager.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,8 +0,0 @@
-<div class="navigation">
-	{ifeq(moreposts,1)}
-	<div class="alignleft"><a href="?paged={prevpage}">&laquo; Older Entries</a></div>
-	{endif()}
-	{ifgt(curpage,0)}
-	<div class="alignright"><a href="?paged={nextpage}">Newer Entries &raquo;</a></div>
-	{endif()}
-</div>
--- a/templates/html/sidebar.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,31 +0,0 @@
-</div>
-
-<!-- begin sidebar -->
-<div id="sidebar">
-
-<div class="sbsection">
-	<ul>
-		<li><a href="http://sandeen.net/wordpress/">Eric Sandeen</a></li>
-		<li><a href="http://blog.unixcat.org">Nur Hussein</a></li>
-	</ul>
-</div>
-
-<div class="sbsection">
-	<ul>
-		<li><a href="http://planet.lilug.org">Planet LILUG</a></li>
-	</ul>
-</div>
-
-<div class="sbsection"><span class="sbtitle">Tags:</span>
-	<div class="tagcloud">{tagcloud%tagcloud}</div>
-</div>
-
-<div class="sbsection"><span class="sbtitle">Meta:</span>
-	<ul>
-		<li><a href="{baseurl}/?feed=atom" title="Syndicate this site using ATOM">Atom</a></li>
-	</ul>
-</div>
-
-</div>
-<!-- end sidebar -->
-
--- a/templates/html/story.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,38 +0,0 @@
-<div class="story">
-	<h2 class="storytitle">{ifset(preview)}Preview: {endif()}<a href="?p={id}" rel="bookmark">{title|escape}</a></h2>
-	<div class="storymeta">
-		Filed under:
-		<ul>
-{tags%tag}
-		</ul>
-		&#8212; JeffPC @ <span title="{time|zulu}">{time|date} {time|time}</span>
-	</div>
-
-{ifset(preview)}
-	<br/>
-	<div style="border: 3px solid red; width: 90%">
-{ifset(twitteruser)}
-{ifset(twittertitle)}
-{ifset(twitterdesc)}
-{ifset(twitterimg)}
-	<div>
-	<img src="{twitterimg}" width="100%" />
-	</div>
-{endif()}
-	<strong>{twittertitle|escape}</strong><br/>
-	<small>{twitterdesc|escape}</small>
-{endif()}
-{endif()}
-{endif()}
-	</div>
-{endif()}
-
-	<div class="storycontent">
-{body}
-	</div>
-
-	<div class="storyfeedback">
-		<a href="?p={id}#respond" title="Comment on {title|escape}">Comments ({numcom})</a>
-	</div>
-</div>
-
--- a/templates/html/storyview.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,4 +0,0 @@
-{header}
-{posts%fullstory}
-{sidebar}
-{footer}
--- a/templates/html/tag.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,1 +0,0 @@
-<li><a href="?tag={tags|urlescape}" title="View all posts in {tags}" rel="category">{tags}</a></li>
--- a/templates/html/tagcloud.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,1 +0,0 @@
-<a href="?tag={name|urlescape}" title="Tag: {name} ({count})" style="font-size: {size}pt;">{name}</a>
--- a/templates/html/tagindex.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,5 +0,0 @@
-{header}
-{posts%story}
-{tagpager}
-{sidebar}
-{footer}
--- a/templates/html/tagpager.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,8 +0,0 @@
-<div class="navigation">
-	{ifeq(moreposts,1)}
-	<div class="alignleft"><a href="?tag={tagid}&amp;paged={prevpage}">&laquo; Older Entries</a></div>
-	{endif()}
-	{ifgt(curpage,0)}
-	<div class="alignright"><a href="?tag={tagid}&amp;paged={nextpage}">Newer Entries &raquo;</a></div>
-	{endif()}
-</div>
--- a/templates/rss2/comment.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,8 +0,0 @@
-<item>
-	<title>By: {commauthor}</title>
-	<guid>{baseurl}/?p={id}#comment-{commid}</guid>
-	<link>{baseurl}/?p={id}#comment-{commid}</link>
-	<comments>{baseurl}/?p={id}#respond</comments>
-	<description><![CDATA[{commbody}]]></description>
-	<pubDate>{commtime|rfc822}</pubDate>
-</item>
--- a/templates/rss2/commentlist.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,16 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<rss version="2.0"
-	xmlns:dc="http://purl.org/dc/elements/1.1/"
-	xmlns:atom="http://www.w3.org/2005/Atom"
->
-<channel>
-	<title>Comments on: {title|escape}</title>
-	<atom:link href="{baseurl}/?p={id}&amp;feed=rss2" rel="self" type="application/rss+xml" />
-	<link>{baseurl}/p={id}</link>
-	<language>en</language>
-	<description>{title|escape}</description>
-	<pubDate>{time|rfc822}</pubDate>
-
-{comments%comment}
-</channel>
-</rss>
--- a/templates/rss2/index.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,16 +0,0 @@
-<?xml version="1.0" encoding="UTF-8"?>
-<rss version="2.0"
-	xmlns:dc="http://purl.org/dc/elements/1.1/"
-	xmlns:atom="http://www.w3.org/2005/Atom"
->
-<channel>
-	<title>Josef "Jeff" Sipek</title>
-	<atom:link href="{baseurl}/?feed=rss2" rel="self" type="application/rss+xml" />
-	<link>{baseurl}</link>
-	<language>en</language>
-	<description>Josef "Jeff" Sipek</description>
-	<pubDate>{lastupdate|rfc822}</pubDate>
-
-{posts%story}
-</channel>
-</rss>
--- a/templates/rss2/story.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,9 +0,0 @@
-<item>
-	<title>{title|escape}</title>
-	<guid>{baseurl}/?p={id}</guid>
-	<link>{baseurl}/?p={id}</link>
-	<comments>{baseurl}/?p={id}#respond</comments>
-	{tags%tag}
-	<description><![CDATA[{body}]]></description>
-	<pubDate>{time|rfc822}</pubDate>
-</item>
--- a/templates/rss2/storyview.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,1 +0,0 @@
-../common/storyview.tmpl
\ No newline at end of file
--- a/templates/rss2/tag.tmpl	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,1 +0,0 @@
-	<category>{tags}</category>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/atom/comment.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,14 @@
+<entry>
+	<author>
+		<name>{commauthor|escape}</name>
+		<uri>{baseurl}/p={id}#comment-{commid}</uri>
+	</author>
+	<title type="html"><![CDATA[By: {commauthor}]]></title>
+	<link rel="alternate" type="text/html" href="{baseurl}/?p={id}#comment-{commid}" />
+	<id>{baseurl}/?p={id}#comment-{commid}</id>
+	<updated>{commtime|zulu}</updated>
+	<published>{commtime|zulu}</published>
+
+	<summary type="html"><![CDATA[{commbody}]]></summary>
+	<content type="html" xml:base="{baseurl}/?p={id}#comment-{commid}"><![CDATA[{commbody}]]></content>
+</entry>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/atom/commentlist.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,18 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<feed
+  xmlns="http://www.w3.org/2005/Atom"
+  xmlns:thr="http://purl.org/syndication/thread/1.0"
+  xml:lang="en"
+  xml:base="{baseurl}/?p={id}&amp;feed=atom"
+   >
+	<updated>{time|zulu}</updated>
+	<title type="text">Comments on: {title|escape}</title>
+
+	<generator uri="http://hg.31bits.net/blahgd/blahgd" version="{generatorversion}">blahgd</generator>
+
+	<link rel="alternate" type="text/html" href="{baseurl}" />
+	<id>{baseurl}/?p={id}&amp;feed=atom</id>
+	<link rel="self" type="application/atom+xml" href="{baseurl}/?p={id}&amp;feed=atom" />
+
+{comments%comment}
+</feed>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/atom/index.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,19 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<feed
+  xmlns="http://www.w3.org/2005/Atom"
+  xmlns:thr="http://purl.org/syndication/thread/1.0"
+  xml:lang="en"
+  xml:base="{baseurl}/?feed=atom"
+   >
+	<updated>{lastupdate|zulu}</updated>
+	<title type="text">Josef "Jeff" Sipek</title>
+	<subtitle type="text">Wasting time effectively</subtitle>
+
+	<generator uri="http://hg.31bits.net/blahgd/blahgd" version="{generatorversion}">blahgd</generator>
+
+	<link rel="alternate" type="text/html" href="{baseurl}" />
+	<id>{baseurl}/?feed=atom</id>
+	<link rel="self" type="application/atom+xml" href="{baseurl}/?feed=atom" />
+
+{posts%story}
+</feed>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/atom/story.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,17 @@
+<entry>
+	<author>
+		<name>JeffPC</name>
+		<uri>{baseurl}</uri>
+	</author>
+	<title type="html"><![CDATA[{title}]]></title>
+	<link rel="alternate" type="text/html" href="{baseurl}/?p={id}" />
+	<id>{baseurl}/?p={id}</id>
+	<updated>{time|zulu}</updated>
+	<published>{time|zulu}</published>
+
+	<link rel="replies" type="text/html" href="{baseurl}/?p={id}#comments" thr:count="1"/>
+	<thr:total>{numcom}</thr:total>
+	{tags%tag}
+	<summary type="html"><![CDATA[{body}]]></summary>
+	<content type="html" xml:base="{baseurl}/?p={id}"><![CDATA[{body}]]></content>
+</entry>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/atom/storyview.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,1 @@
+../common/storyview.tmpl
\ No newline at end of file
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/atom/tag.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,1 @@
+	<category scheme="{baseurl}" term="{tags}" />
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/common/storyview.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,1 @@
+{posts%commentlist}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/301.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,8 @@
+<html>
+<head>
+<title>301 Moved Permanently</title>
+</head>
+<body>
+Moved permanently to <a href="{redirect}">{redirect}</a>.
+</body>
+</html>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/404.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,9 @@
+{header}
+<h2>Page Not Found</h2>
+<div class="post" id="error">
+	<div class="storycontent">
+The page you requested could not be found.
+	</div>
+</div>
+{sidebar}
+{footer}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/archive.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,5 @@
+{header}
+{posts%story}
+{archivepager}
+{sidebar}
+{footer}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/archivepager.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,8 @@
+<div class="navigation">
+	{ifeq(moreposts,1)}
+	<div class="alignleft"><a href="?m={archid}&amp;paged={prevpage}">&laquo; Older Entries</a></div>
+	{endif()}
+	{ifgt(curpage,0)}
+	<div class="alignright"><a href="?m={archid}&amp;paged={nextpage}">Newer Entries &raquo;</a></div>
+	{endif()}
+</div>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/comment.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,4 @@
+	<li id="comment-{commid}">
+{commbody}
+	<p><cite>Comment by {commauthor} &#8212; {commtime|date} @ <a href="#comment-{commid}">{commtime|time}</a></cite></p>
+	</li>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/comment_error.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,8 @@
+{header}
+<h4>Error Saving Comment</h4>
+
+<p>{comment_error_str}</p>
+
+<p>Press the back button in your browser, and try again.</p>
+{sidebar}
+{footer}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/comment_saved.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,4 @@
+{header}
+<h4>Your comment has been held for moderation. Thank you.</h4>
+{sidebar}
+{footer}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/commentform.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,31 @@
+<div id="respond">
+<h2>Leave a comment</h2>
+
+<form action="?comment=1" method="post" id="commentform">
+
+<p style="display: none;">
+<input type="text" name="x" id="name" value="" size="22" />
+<label for="name"><small>Please do not enter anything here</small></label>
+</p>
+
+<p><input type="text" name="a" id="author" value="" size="22" tabindex="1" />
+<label for="author"><small>Name (required)</small></label></p>
+
+<p><input type="text" name="e" id="email" value="" size="22" tabindex="2" />
+<label for="email"><small>Mail (will not be published) (required)</small></label></p>
+
+<p><input type="text" name="u" id="url" value="" size="22" tabindex="3" />
+<label for="url"><small>Website</small></label></p>
+
+<p><input type="text" name="v" id="captcha" value="" size="22" tabindex="4" />
+<label for="captcha"><small>{captcha_a} + {captcha_b} (required)</small></label></p>
+
+<p><textarea name="c" id="comment" cols="100%" rows="10" tabindex="5"></textarea></p>
+
+<p><input name="s" type="submit" id="submit" tabindex="6" value="Submit Comment" />
+<input type="hidden" name="i" value="{id}" />
+<input type="hidden" name="d" value="{now}" />
+</p>
+
+</form>
+</div>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/error_comment_feed.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,10 @@
+{header}
+<h2>Comment feed not yet supported</h2>
+<div class="post" id="error">
+	<div class="storycontent">
+	It turns out that there are some features that I never got around to
+	implementing.  You just found one of them.  Eventually.
+	</div>
+</div>
+{sidebar}
+{footer}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/error_unsupported_feed_fmt.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,10 @@
+{header}
+<h2>Sorry, Atom &amp; RSS2 only</h2>
+<div class="post" id="error">
+	<div class="storycontent">
+	Sorry, currently I support only Atom and RSS2 feeds.  Feel free to
+	contact me if you cannot live without some other feed format.
+	</div>
+</div>
+{sidebar}
+{footer}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/footer.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,9 @@
+
+<!-- begin footer -->
+
+<p class="credit"><cite>Powered by <a href='http://hg.31bits.net/blahgd/blahgd' title='Powered by blahgd'><strong>blahgd</strong></a></cite></p>
+
+</div>
+
+</body>
+</html>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/fullstory.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,12 @@
+{story}
+<h2>{numcom} Comments <a href="#respond" title="Leave a comment">&raquo;</a></h2>
+
+{ifgt(numcom,0)}
+<ol id="commentlist">
+{comments%comment}
+</ol>
+{endif()}
+
+<p><a href='{baseurl}/?p={id}&amp;feed=atom'>Atom feed for comments on this post.</a></p>
+
+{commentform}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/header.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,38 @@
+<!DOCTYPE html>
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
+<head>
+	<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
+	<title>Josef &#8220;Jeff&#8221; Sipek &raquo; {title|escape}</title>
+	<meta name="generator" content="blahgd {generatorversion}" />
+{ifset(twitteruser)}
+{ifset(twittertitle)}
+{ifset(twitterdesc)}
+	<meta name="twitter:site" content="@{twitteruser}" />
+	<meta name="twitter:creator" content="@{twitteruser}" />
+	<meta name="twitter:title" content="{twittertitle|escape}" />
+	<meta name="twitter:description" content="{twitterdesc|escape}" />
+{ifset(twitterimg)}
+	<meta name="twitter:image" content="{twitterimg}" />
+	<meta name="twitter:card" content="summary_large_image" />
+{else()}
+	<meta name="twitter:card" content="summary" />
+{endif()}
+{endif()}
+{endif()}
+{endif()}
+	<style media="screen">
+		@import url( {baseurl}/style.css );
+	</style>
+
+	<link rel="shortcut icon" href="{baseurl}/favicon.ico" />
+	<link rel="alternate" type="application/atom+xml" title="Atom 0.3" href="{baseurl}/?feed=atom" />
+	<link rel="alternate" type="application/rss+xml" title="RSS2" href="{baseurl}/?feed=rss2" />
+</head>
+<body>
+
+<div>
+<h1 id="header"><a href="{baseurl}/">Josef &#8220;Jeff&#8221; Sipek</a></h1>
+
+<div id="content">
+<!-- end header -->
+
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/index.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,5 @@
+{header}
+{posts%story}
+{indexpager}
+{sidebar}
+{footer}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/indexpager.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,8 @@
+<div class="navigation">
+	{ifeq(moreposts,1)}
+	<div class="alignleft"><a href="?paged={prevpage}">&laquo; Older Entries</a></div>
+	{endif()}
+	{ifgt(curpage,0)}
+	<div class="alignright"><a href="?paged={nextpage}">Newer Entries &raquo;</a></div>
+	{endif()}
+</div>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/sidebar.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,31 @@
+</div>
+
+<!-- begin sidebar -->
+<div id="sidebar">
+
+<div class="sbsection">
+	<ul>
+		<li><a href="http://sandeen.net/wordpress/">Eric Sandeen</a></li>
+		<li><a href="http://blog.unixcat.org">Nur Hussein</a></li>
+	</ul>
+</div>
+
+<div class="sbsection">
+	<ul>
+		<li><a href="http://planet.lilug.org">Planet LILUG</a></li>
+	</ul>
+</div>
+
+<div class="sbsection"><span class="sbtitle">Tags:</span>
+	<div class="tagcloud">{tagcloud%tagcloud}</div>
+</div>
+
+<div class="sbsection"><span class="sbtitle">Meta:</span>
+	<ul>
+		<li><a href="{baseurl}/?feed=atom" title="Syndicate this site using ATOM">Atom</a></li>
+	</ul>
+</div>
+
+</div>
+<!-- end sidebar -->
+
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/story.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,38 @@
+<div class="story">
+	<h2 class="storytitle">{ifset(preview)}Preview: {endif()}<a href="?p={id}" rel="bookmark">{title|escape}</a></h2>
+	<div class="storymeta">
+		Filed under:
+		<ul>
+{tags%tag}
+		</ul>
+		&#8212; JeffPC @ <span title="{time|zulu}">{time|date} {time|time}</span>
+	</div>
+
+{ifset(preview)}
+	<br/>
+	<div style="border: 3px solid red; width: 90%">
+{ifset(twitteruser)}
+{ifset(twittertitle)}
+{ifset(twitterdesc)}
+{ifset(twitterimg)}
+	<div>
+	<img src="{twitterimg}" width="100%" />
+	</div>
+{endif()}
+	<strong>{twittertitle|escape}</strong><br/>
+	<small>{twitterdesc|escape}</small>
+{endif()}
+{endif()}
+{endif()}
+	</div>
+{endif()}
+
+	<div class="storycontent">
+{body}
+	</div>
+
+	<div class="storyfeedback">
+		<a href="?p={id}#respond" title="Comment on {title|escape}">Comments ({numcom})</a>
+	</div>
+</div>
+
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/storyview.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,4 @@
+{header}
+{posts%fullstory}
+{sidebar}
+{footer}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/tag.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,1 @@
+<li><a href="?tag={tags|urlescape}" title="View all posts in {tags}" rel="category">{tags}</a></li>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/tagcloud.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,1 @@
+<a href="?tag={name|urlescape}" title="Tag: {name} ({count})" style="font-size: {size}pt;">{name}</a>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/tagindex.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,5 @@
+{header}
+{posts%story}
+{tagpager}
+{sidebar}
+{footer}
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/html/tagpager.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,8 @@
+<div class="navigation">
+	{ifeq(moreposts,1)}
+	<div class="alignleft"><a href="?tag={tagid}&amp;paged={prevpage}">&laquo; Older Entries</a></div>
+	{endif()}
+	{ifgt(curpage,0)}
+	<div class="alignright"><a href="?tag={tagid}&amp;paged={nextpage}">Newer Entries &raquo;</a></div>
+	{endif()}
+</div>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/rss2/comment.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,8 @@
+<item>
+	<title>By: {commauthor}</title>
+	<guid>{baseurl}/?p={id}#comment-{commid}</guid>
+	<link>{baseurl}/?p={id}#comment-{commid}</link>
+	<comments>{baseurl}/?p={id}#respond</comments>
+	<description><![CDATA[{commbody}]]></description>
+	<pubDate>{commtime|rfc822}</pubDate>
+</item>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/rss2/commentlist.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,16 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<rss version="2.0"
+	xmlns:dc="http://purl.org/dc/elements/1.1/"
+	xmlns:atom="http://www.w3.org/2005/Atom"
+>
+<channel>
+	<title>Comments on: {title|escape}</title>
+	<atom:link href="{baseurl}/?p={id}&amp;feed=rss2" rel="self" type="application/rss+xml" />
+	<link>{baseurl}/p={id}</link>
+	<language>en</language>
+	<description>{title|escape}</description>
+	<pubDate>{time|rfc822}</pubDate>
+
+{comments%comment}
+</channel>
+</rss>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/rss2/index.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,16 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<rss version="2.0"
+	xmlns:dc="http://purl.org/dc/elements/1.1/"
+	xmlns:atom="http://www.w3.org/2005/Atom"
+>
+<channel>
+	<title>Josef "Jeff" Sipek</title>
+	<atom:link href="{baseurl}/?feed=rss2" rel="self" type="application/rss+xml" />
+	<link>{baseurl}</link>
+	<language>en</language>
+	<description>Josef "Jeff" Sipek</description>
+	<pubDate>{lastupdate|rfc822}</pubDate>
+
+{posts%story}
+</channel>
+</rss>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/rss2/story.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,9 @@
+<item>
+	<title>{title|escape}</title>
+	<guid>{baseurl}/?p={id}</guid>
+	<link>{baseurl}/?p={id}</link>
+	<comments>{baseurl}/?p={id}#respond</comments>
+	{tags%tag}
+	<description><![CDATA[{body}]]></description>
+	<pubDate>{time|rfc822}</pubDate>
+</item>
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/rss2/storyview.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,1 @@
+../common/storyview.tmpl
\ No newline at end of file
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/rss2/tag.tmpl	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,1 @@
+	<category>{tags}</category>
Binary file theme/static/bug.png has changed
Binary file theme/static/favicon.ico has changed
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/theme/static/style.css	Fri Jul 24 14:21:47 2020 -0400
@@ -0,0 +1,200 @@
+/* tags */
+a {
+	color: black;
+}
+
+a img {
+	border: none;
+}
+
+abbr, acronym {
+	border-bottom: 1px dashed #333333;
+	cursor: help;
+}
+
+blockquote {
+	border-left: 5px solid #ccc;
+	margin-left: 1.5em;
+	padding-left: 5px;
+}
+
+body {
+	background-color: #ffffcc;
+	color: black;
+	margin: 20px;
+	font-size: 12pt;
+}
+
+cite {
+	font-size: 90%;
+	font-style: normal;
+}
+
+h1, h2, h3, h4 {
+	color: #336699;
+}
+
+h1 {
+	font-size: 22pt;
+}
+
+h2 {
+	font-size: 18pt;
+}
+
+h3 {
+	font-size: 14pt;
+}
+
+h4 {
+	font-size: 12pt;
+}
+
+/* ids */
+#header {
+	color: #336699;
+}
+
+#header a {
+	color: #336699;
+	text-decoration: none;
+}
+
+#header a:hover {
+	text-decoration: underline;
+}
+
+#commentform input, #commentform textarea {
+	background: #fff;
+	border: 1px solid #333;
+	padding: .2em;
+}
+
+#commentform textarea {
+	width: 100%;
+}
+
+#content {
+	margin: 30px 11em 0 0em;
+	padding-right: 60px;
+}
+
+#sidebar {
+	font-family: sans-serif;
+	background: white;
+	color: #336699;
+	border-left: 1px dotted #ccc;
+	border-top: 3px solid #e0e6e0;
+	padding: 20px 0 10px 30px;
+	position: absolute;
+	right: 2px;
+	top: 0;
+	width: 11em;
+	text-transform: lowercase;
+}
+
+#sidebar a:hover {
+	border-bottom: 1px solid #809080;
+}
+
+/* classes */
+.alignright {
+	float: right;
+}
+
+.alignleft {
+	float: left
+}
+
+.credit {
+	background: #90a090;
+	border-top: double 3px #aba;
+	color: white;
+	font-size: 11px;
+	margin: 10px 0 0 0;
+	padding: 3px;
+	text-align: center;
+}
+
+.credit a:link, .credit a:hover {
+	color: white;
+}
+
+.navigation {
+	display: block;
+	margin-top: 10px;
+	margin-bottom: 60px;
+}
+
+.sbsection {
+	font-size: 12px;
+	line-height: 115%;
+}
+
+.sbsection ul {
+	list-style-type: none;
+	margin-top: 0;
+	margin-bottom: 10px;
+	padding-left: 0px;
+}
+
+.sbsection a {
+	text-decoration: none;
+}
+
+.sbtitle {
+	font-size: 115%;
+}
+
+.story {
+	padding-bottom: 1em;
+}
+
+.storycontent {
+}
+
+.storycontent pre {
+	font-size: 85%;
+}
+
+.storyfeedback {
+	text-align: right;
+	clear: both;
+}
+
+.storymeta {
+	font-size: .75em;
+}
+
+.storymeta, .storymeta a {
+	font-weight: normal;
+	letter-spacing: 0;
+	color: #808080;
+}
+
+.storymeta li {
+	display: inline;
+}
+
+.storymeta ul {
+	display: inline;
+	list-style: none;
+	margin: 0;
+	padding: 0;
+}
+
+.storytitle {
+	margin: 0;
+}
+
+.storytitle a {
+	text-decoration: none;
+}
+
+.tagcloud {
+	margin-bottom: 10px;
+}
+
+.tt {
+	font-family: monospace;
+}
Binary file theme/static/wiki.png has changed
Binary file web/bug.png has changed
Binary file web/favicon.ico has changed
--- a/web/style.css	Thu Jul 30 16:57:38 2020 -0400
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,200 +0,0 @@
-/* tags */
-a {
-	color: black;
-}
-
-a img {
-	border: none;
-}
-
-abbr, acronym {
-	border-bottom: 1px dashed #333333;
-	cursor: help;
-}
-
-blockquote {
-	border-left: 5px solid #ccc;
-	margin-left: 1.5em;
-	padding-left: 5px;
-}
-
-body {
-	background-color: #ffffcc;
-	color: black;
-	margin: 20px;
-	font-size: 12pt;
-}
-
-cite {
-	font-size: 90%;
-	font-style: normal;
-}
-
-h1, h2, h3, h4 {
-	color: #336699;
-}
-
-h1 {
-	font-size: 22pt;
-}
-
-h2 {
-	font-size: 18pt;
-}
-
-h3 {
-	font-size: 14pt;
-}
-
-h4 {
-	font-size: 12pt;
-}
-
-/* ids */
-#header {
-	color: #336699;
-}
-
-#header a {
-	color: #336699;
-	text-decoration: none;
-}
-
-#header a:hover {
-	text-decoration: underline;
-}
-
-#commentform input, #commentform textarea {
-	background: #fff;
-	border: 1px solid #333;
-	padding: .2em;
-}
-
-#commentform textarea {
-	width: 100%;
-}
-
-#content {
-	margin: 30px 11em 0 0em;
-	padding-right: 60px;
-}
-
-#sidebar {
-	font-family: sans-serif;
-	background: white;
-	color: #336699;
-	border-left: 1px dotted #ccc;
-	border-top: 3px solid #e0e6e0;
-	padding: 20px 0 10px 30px;
-	position: absolute;
-	right: 2px;
-	top: 0;
-	width: 11em;
-	text-transform: lowercase;
-}
-
-#sidebar a:hover {
-	border-bottom: 1px solid #809080;
-}
-
-/* classes */
-.alignright {
-	float: right;
-}
-
-.alignleft {
-	float: left
-}
-
-.credit {
-	background: #90a090;
-	border-top: double 3px #aba;
-	color: white;
-	font-size: 11px;
-	margin: 10px 0 0 0;
-	padding: 3px;
-	text-align: center;
-}
-
-.credit a:link, .credit a:hover {
-	color: white;
-}
-
-.navigation {
-	display: block;
-	margin-top: 10px;
-	margin-bottom: 60px;
-}
-
-.sbsection {
-	font-size: 12px;
-	line-height: 115%;
-}
-
-.sbsection ul {
-	list-style-type: none;
-	margin-top: 0;
-	margin-bottom: 10px;
-	padding-left: 0px;
-}
-
-.sbsection a {
-	text-decoration: none;
-}
-
-.sbtitle {
-	font-size: 115%;
-}
-
-.story {
-	padding-bottom: 1em;
-}
-
-.storycontent {
-}
-
-.storycontent pre {
-	font-size: 85%;
-}
-
-.storyfeedback {
-	text-align: right;
-	clear: both;
-}
-
-.storymeta {
-	font-size: .75em;
-}
-
-.storymeta, .storymeta a {
-	font-weight: normal;
-	letter-spacing: 0;
-	color: #808080;
-}
-
-.storymeta li {
-	display: inline;
-}
-
-.storymeta ul {
-	display: inline;
-	list-style: none;
-	margin: 0;
-	padding: 0;
-}
-
-.storytitle {
-	margin: 0;
-}
-
-.storytitle a {
-	text-decoration: none;
-}
-
-.tagcloud {
-	margin-bottom: 10px;
-}
-
-.tt {
-	font-family: monospace;
-}
Binary file web/wiki.png has changed
--- a/samples/full.lisp	Thu Jul 30 16:57:38 2020 -0400
+++ b/samples/full.lisp	Fri Jul 24 14:21:47 2020 -0400
@@ -25,11 +25,12 @@
  ; contains a directory for each post.
  (data-dir . "/blahg/data")
 
- ; The location of the web directory with static files.  Default is "./web".
- (web-dir . "/blahg/web")
+ ; The location of the web directory with static files.  Default is
+ ; "./theme/static".
+ (web-dir . "/blahg/theme/static")
 
- ; The location of the templates directory.  Default is "./templates".
- (template-dir . "/blahg/templates")
+ ; The location of the templates directory.  Default is "./theme".
+ (template-dir . "/blahg/theme")
 
  ; The base URL for the blahg.  This is the URL for the index page.
  (base-url . "http://blahg.example.com")